@@ -75,6 +75,10 @@ class ChangePasswordSerializer(serializers.Serializer, ValidatePasswordMixin):
         return data
 
 
+class ChangeEmailSerializer(serializers.Serializer):
+    new_email = serializers.EmailField()
+
+
 class RemindPasswordSerializer(serializers.Serializer):
     email = serializers.EmailField()
 
